.TH iludp G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
iludp - ILUD with column pivoting
.SH CALLING SEQUENCE
.nf
[L,U,perm,ierr]=iludp(A,alph,tol,ptol,bloc)
.fi
.SH PARAMETERS
.TP
A
: sparse matrix (must be square)
.TP
alph
: the diagonal compensation parameter; \fValph\fR uses the default 0.5
.TP
tol
: tolerance used for dropping elements in L and U; \fVtol\fR uses the default 0.001*max(Aij)
.TP
ptol
: tolerance ratio used for determning whether to permute two columns. \fVptol\fR uses the default, 0.5
.TP
bloc
: permuting can be done within the diagonal blocks of size mbloc. \fVbloc\fR uses the default n, with n the size of A
.TP
L
: lower triangular matrix
.TP
U
: upper triangular matrix
.TP
perm
: contains the permutation arrays
.TP
ierr
: error message
.SH DESCRIPTION
\fV[L,U,perm,ierr]=iludp(A,alph,tol,ptol,bloc)\fR builds an incomplete LU factorization of the sparse matrix \fVA\fR. The two factors L and U are stored in the CSR format. The CSR format is the Compressed Sparse Row format used by Scilab. The A matrix must be square.
.TP 
alph
: The term \fValph\fR*(sum of all dropped out elements in a given row) is added to the diagonal element of U of the factorization. Thus:
.LF
   alph = 0 ---> ~ ILU with threshold,
.LF
   alph = 1 ---> ~ MILU with threshold.
.TP
ptol
: Two columns are permuted only when abs(a(i,j))*\fVptol\fR .gt. abs(a(i,i)) [0 --> never permute; good values 0.1 to 0.01]
.TP
bloc
: Useful for PDE problems with several degrees of freedom. If feature not wanted take \fVbloc\fR=n.
.TP
ierr
: Error message with the following meaning.
.LP
   0  --> successful return.
.LP
  >0  --> zero pivot encountered at step number ierr.
.LP
  -1  --> Error. input matrix may be wrong. (The elimination process has generated a row in L or U whose length is .gt.  n.)
.LP
  -2  --> The L/U matrix overflows the arrays alu,jlu
.LP
  -3  --> zero row encountered.
.SH EXAMPLE
.nf
A=mmread(SCILIN+'/demos/matrices/nos1.mtx')
n=size(A,1); b=ones(n,1);
alph=0;tol=0;ptol=0;bloc=3;
[L,U,iperm,ierr]=iludp(A,alph,tol,ptol,bloc);
x=U\(L\b)
A*x-b
.fi
.SH AUTHOR
Aladin Group & Yousef Saad
.SH SEE ALSO
ilud, ilut, milu0, sparse