.TH iluk G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
iluk - level-k of the sparse incomplete lu factorization with dual truncation
.SH CALLING SEQUENCE
.nf
[L,U,ierr]=iluk(A,lfil,elts)
.fi
.SH PARAMETERS
.TP
A
: sparse matrix (must be squared)
.TP
lfil
: the fill-in parameter; \fVlfil\fR uses the default 1
.TP
elts
: maximal number of nonnull elements of the matrices L and U, without diagonal elements; The default of \fVelts\fR is always correct, but over-estimates a lot.
.TP
L
: lower triangular matrix
.TP
U
: upper triangular matrix
.TP
ierr
: error flag
.SH DESCRIPTION
\fV[L,U,ierr]=iluk(A,lfil,elts)\fR builds an incomplete LU factorization of the sparse matrix \fVA\fR. The two factors L and U are stored under a CSR format. The CSR format is the Compressed Sparse Row format used by Scilab.
.LP
All the diagonal elements of the input matrix must be nonzero.
.TP 
lfil
: Each element whose level-of-fill exceeds \fVlfil\fR during the ILU process is dropped. lfil must be .ge. 0 
.TP
ierr
: Error message with the following meaning.
.LP
   0    --> successful return.
.LP
  >0  --> zero pivot encountered at step number ierr.
.LP
  -1   --> Error. input matrix may be wrong. (The elimination process has generated a row in L or U whose length is .gt.  n.)
.LP
  -2   --> The matrix L overflows the array al.
.LP
  -3   --> The matrix U overflows the array alu.
.LP
  -4   --> Illegal value for lfil.
.LP
  -5   --> zero row encountered in A or U.
.SH EXAMPLE
.nf
A=mmread(SCILIN+'/demos/matrices/pde225.mtx')
n=size(A,1); b=ones(n,1);
lfil=10;
[L,U,ierr]=iluk(A,lfil);
x=U\(L\b)
A*x-b
.fi
.SH AUTHOR
Aladin Group & Yousef Saad
.SH SEE ALSO
ilu0, sparse