.TH ilut G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
ilut - sparse incomplete LU factorization with dual truncation
.SH CALLING SEQUENCE
.nf
[L,U,ierr]=ilut(A,lfil,drop)
.fi
.SH PARAMETERS
.TP
A
: sparse matrix (must be square)
.TP
lfil
: the fill-in parameter; The default of \fVlfil\fR is the average number of nonnull elements of the matrix A by lines
.TP
drop
: the threshold for dropping small terms in the factorization; \fVdrop\fR uses the default, 0.001*max(Aij)
.TP
L
: lower triangular matrix
.TP
U
: upper triangular matrix
.TP
ierr
: error flag
.SH DESCRIPTION
\fV[L,U,ierr]=ilut(A,lfil,drop)\fR builds an incomplete LU factorization of the sparse matrix \fVA\fR. The two factors L and U are stored in the CSR format. The CSR format is the Compressed Sparse Row format used by Scilab.
.LP
The diagonal elements of the input matrix must be nonzero (at least 'structurally')
.TP 
lfil
: Each row of L and each row of U will have a maximum of \fVlfil\fR elements (excluding the diagonal element). lfil must be .ge. 0.
.TP
drop
: Sets the threshold for dropping small terms in the factorization. The dual drop strategy works as follow:
.LP
1) Theresholding in L and U as set by droptol. Any element whose magnitude is less than some tolerance (relative to the abs value of diagonal element in u) is dropped.
.LP
2) Keeping only the largest lfil elements in the i-th row of L and the largest lfil elements in the i-th row of U (excluding diagonal elements).
.LP
Flexibility: one can use \fVdrop=0\fR to get a strategy based on keeping the largest elements in each row of L and U. Taking droptol .ne. 0 but lfil=n, will give threshold strategy (however, fill-in is then mpredictible).
.TP
ierr
: Error message with the following meaning.
.LP
   0    --> successful return.
.LP
  >0  --> zero pivot encountered at step number ierr.
.LP
  -1   --> Error. input matrix may be wrong. (The elimination process has generated a row in L or U whose length is .gt.  n.)
.LP
  -2   --> The matrix L overflows the array al.
.LP
  -3   --> The matrix U overflows the array alu.
.LP
  -4   --> Illegal value for lfil.
.LP
  -5   --> zero row encountered.
.SH EXAMPLE
.nf
A=mmread(SCILIN+'/demos/matrices/nos1.mtx')
n=size(A,1); b=ones(n,1);
lfil=10;drop=0;
[L,U,ierr]=ilut(A,lfil,drop);
x=U\(L\b)
A*x-b
.fi
.SH AUTHOR
Aladin Group & Yousef Saad
.SH SEE ALSO
ilutp, sparse
